//	ATmega48/88/168 Special Function Registers

enum SFR
{
    PINB	= 0x23,
	DDRB,
	PORTB,
	PINC,
	DDRC,
	PORTC,
	PIND,
	DDRD,
	PORTD,
	
	TIFR0	= 0x35,
	TIFR1,
	TIFR2,
	
	PCIFR	= 0x3b,
	EIFR,
	EIMSK,
	GPIOR0,
	EECR,
	EEDR,
	EEARL,
	EEARH,
	GTCCR,
	TCCR0A,
	TCCR0B,
	TCNT0,
	OCR0A,
	OCR0B,
	
	GPIOR1	= 0x4a,
	GPIOR2,
	SPCR,
	SPSR,
	SPDR,
	
	ACSR	= 0x50,
	
	SMCR	= 0x53,
	MCUSR,
	MCUCR,
	
	SPMCSR	= 0x57,
	
	SPL		= 0x5d,
	SPH,
	SREG,
	WDTCSR,
	CLKPR,
	
	PRR		= 0x64,
	
	OSCCAL	= 0x66,
	
	PCICR	= 0x68,
	EICRA,
	
	PCMSK0	= 0x6b,
	PCMSK1,
	PCMSK2,
	TIMSK0,
	TIMSK1,
	TIMSK2,
	
	ADCL	= 0x78,
	ADCH,
	ADCSRA,
	ADCSRB,
	ADMUX,
	
	DIDR0	= 0x7e,
	DIDR1,
	TCCR1A,
	TCCR1B,
	TCCR1C,
	
	TCNT1L	= 0x84,
	TCNT1H,
	ICR1L,
	ICR1H,
	OCR1AL,
	OCR1AH,
	OCR1BL,
	OCR1BH,
	
	TCCR2A	= 0xb0,
	TCCR2B,
	TCNT2,
	OCR2A,
	OCR2B,
	
	ASSR	= 0xb6,
	
	TWBR	= 0xb8,
	TWSR,
	TWAR,
	TWDR,
	TWCR,
	TWAMR,
	
	UCSR0A	= 0xc0,
	UCSR0B,
	UCSR0C,
	
	UBRR0L	= 0xc4,
	UBRR0H,
	UDR0
};

/* I/O registers */
/* avr/iomx8.h - definitions for ATmega48, ATmega88 and ATmega168 */
//Register Bit
//WinAVR-20080610iomx8.hH
//N.A. -- Not Available
struct RB
{
	public const int

/* PINB */
	PINB7	= 7,
	PINB6	= 6,
	PINB5	= 5,
	PINB4	= 4,
	PINB3	= 3,
	PINB2	= 2,
	PINB1	= 1,
	PINB0	= 0,

/* DDRB */
	DDB7	= 7,
	DDB6	= 6,
	DDB5	= 5,
	DDB4	= 4,
	DDB3	= 3,
	DDB2	= 2,
	DDB1	= 1,
	DDB0	= 0,

/* PORTB */
	PB7	= 7,
	PB6	= 6,
	PB5	= 5,
	PB4	= 4,
	PB3	= 3,
	PB2	= 2,
	PB1	= 1,
	PB0	= 0,

/* PINC */
	PINC6	= 6,
	PINC5	= 5,
	PINC4	= 4,
	PINC3	= 3,
	PINC2	= 2,
	PINC1	= 1,
	PINC0	= 0,

/* DDRC */
	DDC6	= 6,
	DDC5	= 5,
	DDC4	= 4,
	DDC3	= 3,
	DDC2	= 2,
	DDC1	= 1,
	DDC0	= 0,

/* PORTC */
	PC6	= 6,
	PC5	= 5,
	PC4	= 4,
	PC3	= 3,
	PC2	= 2,
	PC1	= 1,
	PC0	= 0,

/* PIND */
	PIND7	= 7,
	PIND6	= 6,
	PIND5	= 5,
	PIND4	= 4,
	PIND3	= 3,
	PIND2	= 2,
	PIND1	= 1,
	PIND0	= 0,

/* DDRD */
	DDD7	= 7,
	DDD6	= 6,
	DDD5	= 5,
	DDD4	= 4,
	DDD3	= 3,
	DDD2	= 2,
	DDD1	= 1,
	DDD0	= 0,

/* PORTD */
	PD7	= 7,
	PD6	= 6,
	PD5	= 5,
	PD4	= 4,
	PD3	= 3,
	PD2	= 2,
	PD1	= 1,
	PD0	= 0,

/* TIFR0 */
	OCF0B	= 2,
	OCF0A	= 1,
	TOV0	= 0,

/* TIFR1 */
	ICF1	= 5,
	OCF1B	= 2,
	OCF1A	= 1,
	TOV1	= 0,

/* TIFR2 */
	OCF2B	= 2,
	OCF2A	= 1,
	TOV2	= 0,

/* PCIFR */
	PCIF2	= 2,
	PCIF1	= 1,
	PCIF0	= 0,

/* EIFR */
	INTF1	= 1,
	INTF0	= 0,

/* EIMSK */
	INT1	= 1,
	INT0	= 0,

/* EECT - EEPROM Control Register */
	EEPM1	= 5,
	EEPM0	= 4,
	EERIE	= 3,
	EEMPE	= 2,
	EEPE	= 1,
	EERE	= 0,

/* GTCCR */
	TSM		= 7,
	PSRASY	= 1,
	PSRSYNC	= 0,

/* TCCR0A */
	COM0A1	= 7,
	COM0A0	= 6,
	COM0B1	= 5,
	COM0B0	= 4,
	WGM01	= 1,
	WGM00	= 0,

/* TCCR0A */
	FOC0A	= 7,
	FOC0B	= 6,
	WGM02	= 3,
	CS02	= 2,
	CS01	= 1,
	CS00	= 0,

/* SPCR */
	SPIE	= 7,
	SPE		= 6,
	DORD	= 5,
	MSTR	= 4,
	CPOL	= 3,
	CPHA	= 2,
	SPR1	= 1,
	SPR0	= 0,

/* SPSR */
	SPIF	= 7,
	WCOL	= 6,
	SPI2X	= 0,

/* ACSR */
	ACD		= 7,
	ACBG	= 6,
	ACO		= 5,
	ACI		= 4,
	ACIE	= 3,
	ACIC	= 2,
	ACIS1	= 1,
	ACIS0	= 0,

/* SMCR */
	SM2	= 3,
	SM1	= 2,
	SM0	= 1,
	SE	= 0,

/* MCUSR */
	WDRF	= 3,
	BORF	= 2,
	EXTRF	= 1,
	PORF	= 0,

/* MCUCR */
	PUD		= 4,
	IVSEL	= 1,	//N.A. ATmega48
	IVCE	= 0,	//N.A. ATmega48

/* SPMCSR */
	SPMIE		= 7,
	RWWSB		= 6,	//N.A. ATmega48
	RWWSRE		= 4,	//N.A. ATmega48
	BLBSET		= 3,
	PGWRT		= 2,
	PGERS		= 1,
	SELFPRGEN	= 0,
	SPMEN		= 0,

/* WDTCSR */
	WDIF	= 7,
	WDIE	= 6,
	WDP3	= 5,
	WDCE	= 4,
	WDE		= 3,
	WDP2	= 2,
	WDP1	= 1,
	WDP0	= 0,

/* CLKPR */
	CLKPCE	= 7,
	CLKPS3	= 3,
	CLKPS2	= 2,
	CLKPS1	= 1,
	CLKPS0	= 0,

/* PRR */
	PRTWI		= 7,
	PRTIM2		= 6,
	PRTIM0		= 5,
	PRTIM1		= 3,
	PRSPI		= 2,
	PRUSART0	= 1,
	PRADC		= 0,

/* PCICR */
	PCIE2	= 2,
	PCIE1	= 1,
	PCIE0	= 0,

/* EICRA */
	ISC11	= 3,
	ISC10	= 2,
	ISC01	= 1,
	ISC00	= 0,

/* PCMSK0 */
	PCINT7	= 7,
	PCINT6	= 6,
	PCINT5	= 5,
	PCINT4	= 4,
	PCINT3	= 3,
	PCINT2	= 2,
	PCINT1	= 1,
	PCINT0	= 0,

/* PCMSK1 */
	PCINT14	= 6,
	PCINT13	= 5,
	PCINT12	= 4,
	PCINT11	= 3,
	PCINT10	= 2,
	PCINT9	= 1,
	PCINT8	= 0,

/* PCMSK2 */
	PCINT23	= 7,
	PCINT22	= 6,
	PCINT21	= 5,
	PCINT20	= 4,
	PCINT19	= 3,
	PCINT18	= 2,
	PCINT17	= 1,
	PCINT16	= 0,

/* TIMSK0 */
	OCIE0B	= 2,
	OCIE0A	= 1,
	TOIE0	= 0,

/* TIMSK1 */
	ICIE1	= 5,
	OCIE1B	= 2,
	OCIE1A	= 1,
	TOIE1	= 0,

/* TIMSK2 */
	OCIE2B	= 2,
	OCIE2A	= 1,
	TOIE2	= 0,

/* ADCSRA */
	ADEN	= 7,
	ADSC	= 6,
	ADATE	= 5,
	ADIF	= 4,
	ADIE	= 3,
	ADPS2	= 2,
	ADPS1	= 1,
	ADPS0	= 0,

/* ADCSRB */
	ACME	= 6,
	ADTS2	= 2,
	ADTS1	= 1,
	ADTS0	= 0,

/* ADMUX */
	REFS1	= 7,
	REFS0	= 6,
	ADLAR	= 5,
	MUX3	= 3,
	MUX2	= 2,
	MUX1	= 1,
	MUX0	= 0,

/* DIDR0 */
	ADC5D	= 5,
	ADC4D	= 4,
	ADC3D	= 3,
	ADC2D	= 2,
	ADC1D	= 1,
	ADC0D	= 0,

/* DIDR1 */
	AIN1D	= 1,
	AIN0D	= 0,

/* TCCR1A */
	COM1A1	= 7,
	COM1A0	= 6,
	COM1B1	= 5,
	COM1B0	= 4,
	WGM11	= 1,
	WGM10	= 0,

/* TCCR1B */
	ICNC1	= 7,
	ICES1	= 6,
	WGM13	= 4,
	WGM12	= 3,
	CS12	= 2,
	CS11	= 1,
	CS10	= 0,

/* TCCR1C */
	FOC1A	= 7,
	FOC1B	= 6,

/* TCCR2A */
	COM2A1	= 7,
	COM2A0	= 6,
	COM2B1	= 5,
	COM2B0	= 4,
	WGM21	= 1,
	WGM20	= 0,

/* TCCR2B */
	FOC2A	= 7,
	FOC2B	= 6,
	WGM22	= 3,
	CS22	= 2,
	CS21	= 1,
	CS20	= 0,

/* ASSR */
	EXCLK	= 6,
	AS2		= 5,
	TCN2UB	= 4,
	OCR2AUB	= 3,
	OCR2BUB	= 2,
	TCR2AUB	= 1,
	TCR2BUB	= 0,

/* TWSR */
	TWS7	= 7,
	TWS6	= 6,
	TWS5	= 5,
	TWS4	= 4,
	TWS3	= 3,
	TWPS1	= 1,
	TWPS0	= 0,

/* TWAR */
	TWA6	= 7,
	TWA5	= 6,
	TWA4	= 5,
	TWA3	= 4,
	TWA2	= 3,
	TWA1	= 2,
	TWA0	= 1,
	TWGCE	= 0,

/* TWCR */
	TWINT	= 7,
	TWEA	= 6,
	TWSTA	= 5,
	TWSTO	= 4,
	TWWC	= 3,
	TWEN	= 2,
	TWIE	= 0,

/* TWAMR */
	TWAM6	= 7,
	TWAM5	= 6,
	TWAM4	= 5,
	TWAM3	= 4,
	TWAM2	= 3,
	TWAM1	= 2,
	TWAM0	= 1,

/* UCSR0A */
	RXC0	= 7,
	TXC0	= 6,
	UDRE0	= 5,
	FE0		= 4,
	DOR0	= 3,
	UPE0	= 2,
	U2X0	= 1,
	MPCM0	= 0,

/* UCSR0B */
	RXCIE0	= 7,
	TXCIE0	= 6,
	UDRIE0	= 5,
	RXEN0	= 4,
	TXEN0	= 3,
	UCSZ02	= 2,
	RXB80	= 1,
	TXB80	= 0,

/* UCSR0C */
	UMSEL01	= 7,
	UMSEL00	= 6,
	UPM01	= 5,
	UPM00	= 4,
	USBS0	= 3,
	UCSZ01	= 2,
	UDORD0	= 2,
	UCSZ00	= 1,
	UCPHA0	= 1,
	UCPOL0	= 0,

	//<,><;>~Xh~
	_ATMEGA48_RB_ENUM_	= 0;
};
